Wraps the OWASP HTML Sanitizer library.
Wraps the OWASP HTML Sanitizer library.
(merge-policies & policies)Merge multiple PolicyFactory and/or option sequences together.
Merge multiple PolicyFactory and/or option sequences together.
(policy & options)Access a predefined policy or create one from a sequence of options.
Access a predefined policy or create one from a sequence of options.
(read-flat-key-val-sequence options)(read-flat-key-val-sequence options key?)Reads a flat sequence of key and (optional) values into proper key-value pairs. Keys are identified by key? returning true.
Reads a flat sequence of key and (optional) values into proper key-value pairs. Keys are identified by key? returning true.
(sanitize html)(sanitize policy html)Apply an HTML sanitization policy (a PolicyFactory object rather than a sequence of options) to a string of HTML.
Apply an HTML sanitization policy (a PolicyFactory object rather than a sequence of options) to a string of HTML.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |