Wraps the PegDown library.
Wraps the PegDown library.
(add-attribs rendering attributes)Adds multiple attributes to- and returns the LinkRenderer$Rendering instance.
Adds multiple attributes to- and returns the LinkRenderer$Rendering instance.
Default LinkRenderer handlers map; Custom handlers can be passed into the link-renderer func where they will be merged with these.
Default LinkRenderer handlers map; Custom handlers can be passed into the link-renderer func where they will be merged with these.
(encode value)Returns an encoded attribute value, as used by Pegdown.
Returns an encoded attribute value, as used by Pegdown.
(encode-url url)Returns an encoded URL, as ued by Pegdown.
Returns an encoded URL, as ued by Pegdown.
(link-renderer handlers)Returns a Pegdown LinkRenderer$Rendering instance, which holds the actual properties of the link as it is going to be rendered. To use custom link renderers, pass in a custom handlers map formatted like like the default-handlers map (the two maps will be merged together).
Returns a Pegdown LinkRenderer$Rendering instance, which holds the actual properties of the link as it is going to be rendered. To use custom link renderers, pass in a custom handlers map formatted like like the default-handlers map (the two maps will be merged together).
(obfuscate email)Returns an obfuscated email address, as used by Pegdown.
Returns an obfuscated email address, as used by Pegdown.
(processor)(processor & exts)Returns a function that produeces PegDownProcessor instances with the given extensions enabled.
Returns a function that produeces PegDownProcessor instances with the given extensions enabled.
(rendering handler node args)Builds and returns Pegdown LinkRenderer. Rendering instance for the node type; args and attributes are set in the node-type's handler. Sets multiple link tag attributes if name/value pairs are supplied in the node handler's attributes vector.
Builds and returns Pegdown LinkRenderer. Rendering instance for the node type; args and attributes are set in the node-type's handler. Sets multiple link tag attributes if name/value pairs are supplied in the node handler's attributes vector.
(select-handler node handlers)Returns the default handler func for the node type.
Returns the default handler func for the node type.
(to-html md)(to-html processor md)(to-html processor link-renderer md)Render a string of Markdown to HTML, optionally using the provided PegDownProcessor and LinkRenderer.
Render a string of Markdown to HTML, optionally using the provided PegDownProcessor and LinkRenderer.
(wiki-url node)(with-attribute rendering attribute)(with-attribute rendering name value)Adds attribute to the LinkRenderer$Rendering instance.
Adds attribute to the LinkRenderer$Rendering instance.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |